import { GeorouterPort } from '../application/ports/georouter.port';
import { GeorouterSettings } from '../application/types/georouter-settings.type';
import { SpacetimePointProps } from './value-objects/timepoint.value-object';
import { WaypointProps } from './value-objects/waypoint.value-object';

// All properties that a Route has
export interface RouteProps {
  name: string;
  distance: number;
  duration: number;
  fwdAzimuth: number;
  backAzimuth: number;
  distanceAzimuth: number;
  waypoints: WaypointProps[];
  spacetimePoints: SpacetimePointProps[];
}

// Properties that are needed for a Route creation
export interface CreateRouteProps {
  roles: Role[];
  waypoints: WaypointProps[];
  georouter: GeorouterPort;
  georouterSettings: GeorouterSettings;
}

export type Path = {
  type: PathType;
  points: Point[];
};

export type Point = {
  lon: number;
  lat: number;
  context?: PointContext;
};

export enum Role {
  DRIVER = 'DRIVER',
  PASSENGER = 'PASSENGER',
}

export enum PointContext {
  HOUSE_NUMBER = 'HOUSE_NUMBER',
  STREET_ADDRESS = 'STREET_ADDRESS',
  LOCALITY = 'LOCALITY',
  VENUE = 'VENUE',
  OTHER = 'OTHER',
}

export enum PathType {
  COMMON = 'common',
  DRIVER = 'driver',
  PASSENGER = 'passenger',
}
